@@ -18,7 +18,8 @@ from functools import partial
 
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
 
-from akerbp.mlops.core import logger, config
+from akerbp.mlops.core import config, logger
+from akerbp.mlops.core.helpers import confirm_prompt
 
 logging=logger.get_logger(name='mlops_cdf')
 
@@ -126,11 +127,6 @@ def delete_function(function_name, confirm=True):
     confirmed = False
 
     if confirm:
-        def confirm_prompt(question):
-            reply = None
-            while reply not in ("y", "n"):
-                reply = input(f"{question} (y/n): ").lower()
-            return (reply == "y")
         question = f"Delete {model=}, {service=}, {environment=}?"
         confirmed = confirm_prompt(question)
 
@@ -601,4 +597,52 @@ def delete_file(id):
     """
     client = global_client["files"]
     client.files.delete(**id)
-    logging.debug(f"Deleted file with {id=}")
\ No newline at end of file
+    logging.debug(f"Deleted file with {id=}")
+
+
+def copy_file(source_ext_id, target_ext_id, overwrite=False):
+    """
+    Copy content and metadata of a file in CDF Files
+
+    Input:
+        - source_ext_id: (str) external id for source file
+        - target_ext_id: (str) external id for target file
+        - overwrite: (bool) should target file be overwritten if it exists
+    """
+    client = global_client["files"]
+    f = client.files.retrieve(external_id=source_ext_id)
+    file_content = client.files.download_bytes(external_id=source_ext_id)
+    logging.debug(f"Downloaded file: {source_ext_id}, {f.dump()}")
+    f = client.files.upload_bytes(
+        file_content, 
+        name=f.name,
+        external_id=target_ext_id,
+        metadata=f.metadata, 
+        directory=f.directory, 
+        overwrite=overwrite
+    )
+    m = f"Copied source {source_ext_id} to {target_ext_id}, {f.dump()}"
+    logging.info(m)
+
+
+def file_exists(external_id, directory):
+    """
+    Check if a file exists in a folder (regardless of uploaded status)
+
+    Input:
+        - external_id: (str)
+        - directory: (str)
+    Output
+        - exists: (bool)
+    """
+    file_list = query_file_versions(
+        directory_prefix=directory, 
+        external_id_prefix=external_id,
+        uploaded=None
+    )
+    if file_list.empty:
+        logging.info(f"File with '{external_id=}' not found")
+        exists =  False
+    else:
+        exists = True
+    return exists
\ No newline at end of file
