@@ -10,15 +10,15 @@ class CDFLogger:
     def __init__(self, base_name):
         self.base_name=base_name
     def debug(self,log):
-        print(f"{self.base_name}-DEBUG-{log}")
+        print(f"{self.base_name} - DEBUG - {log}")
     def info(self,log):
-        print(f"{self.base_name}-INFO-{log}")
+        print(f"{self.base_name} - INFO - {log}")
     def warning(self,log):
-        print(f"{self.base_name}-WARNING-{log}")
+        print(f"{self.base_name} - WARNING - {log}")
     def error(self,log):
-        print(f"{self.base_name}-ERROR-{log}")
+        print(f"{self.base_name} - ERROR - {log}")
     def critical(self,log):
-        print(f"{self.base_name}-CRITICAL-{log}")
+        print(f"{self.base_name} - CRITICAL - {log}")
 
 
 def get_logger(name=base_name, format=default_format):
@@ -27,7 +27,7 @@ def get_logger(name=base_name, format=default_format):
     """
     
     # can't use config module for this one or there would be circular imports
-    if os.getenv("DEPLOYMENT_PLATFORM")=='cdf': 
+    if os.getenv("PLATFORM")=='cdf': 
         return CDFLogger(base_name)
     
     logger = logging.getLogger(name)
